Title: [106649] trunk/Source/WebCore
Revision
106649
Author
[email protected]
Date
2012-02-03 04:49:14 -0800 (Fri, 03 Feb 2012)

Log Message

Do not ASSERT on TouchStationary TouchPoint state.
https://bugs.webkit.org/show_bug.cgi?id=77620

Patch by Allan Sandfeld Jensen <[email protected]> on 2012-02-03
Reviewed by Kenneth Rohde Christiansen.

* page/EventHandler.cpp:
(WebCore::eventNameForTouchPointState): Explicitly show that TouchStationary is asserted.
(WebCore::EventHandler::handleTouchEvent):
    Remove TouchStationary from ASSERT. The value of HitTestRequest is restored to the
    value it should have if hittested, but is not used.

Modified Paths

Diff

Modified: trunk/Source/WebCore/ChangeLog (106648 => 106649)


--- trunk/Source/WebCore/ChangeLog	2012-02-03 12:14:37 UTC (rev 106648)
+++ trunk/Source/WebCore/ChangeLog	2012-02-03 12:49:14 UTC (rev 106649)
@@ -1,3 +1,16 @@
+2012-02-03  Allan Sandfeld Jensen  <[email protected]>
+
+        Do not ASSERT on TouchStationary TouchPoint state.
+        https://bugs.webkit.org/show_bug.cgi?id=77620
+
+        Reviewed by Kenneth Rohde Christiansen.
+
+        * page/EventHandler.cpp:
+        (WebCore::eventNameForTouchPointState): Explicitly show that TouchStationary is asserted.
+        (WebCore::EventHandler::handleTouchEvent):
+            Remove TouchStationary from ASSERT. The value of HitTestRequest is restored to the
+            value it should have if hittested, but is not used.
+
 2012-02-03  Kentaro Hara  <[email protected]>
 
         Add the "ObjC" prefix to ObjC specific IDL attributes

Modified: trunk/Source/WebCore/page/EventHandler.cpp (106648 => 106649)


--- trunk/Source/WebCore/page/EventHandler.cpp	2012-02-03 12:14:37 UTC (rev 106648)
+++ trunk/Source/WebCore/page/EventHandler.cpp	2012-02-03 12:49:14 UTC (rev 106649)
@@ -3281,6 +3281,8 @@
         return eventNames().touchstartEvent;
     case PlatformTouchPoint::TouchMoved:
         return eventNames().touchmoveEvent;
+    case PlatformTouchPoint::TouchStationary:
+        // TouchStationary state is not converted to touch events, so fall through to assert.
     default:
         ASSERT_NOT_REACHED();
         return emptyAtom;
@@ -3336,6 +3338,9 @@
         case PlatformTouchPoint::TouchCancelled:
             hitType |= HitTestRequest::Release;
             break;
+        case PlatformTouchPoint::TouchStationary:
+            hitType |= HitTestRequest::Active | HitTestRequest::ReadOnly;
+            break;
         default:
             ASSERT_NOT_REACHED();
             break;
@@ -3368,7 +3373,7 @@
             // we also remove it from the map.
             touchTarget = m_originatingTouchPointTargets.take(touchPointTargetKey);
         } else
             // No hittest is performed on move, since the target is not allowed to change anyway.
             touchTarget = m_originatingTouchPointTargets.get(touchPointTargetKey);
 
         if (!touchTarget.get())
@@ -3368,7 +3373,7 @@
             touchTarget = m_originatingTouchPointTargets.take(touchPointTargetKey);
         } else
-            // No hittest is performed on move, since the target is not allowed to change anyway.
+            // No hittest is performed on move or stationary, since the target is not allowed to change anyway.
             touchTarget = m_originatingTouchPointTargets.get(touchPointTargetKey);
 
_______________________________________________
webkit-changes mailing list
[email protected]
http://lists.webkit.org/mailman/listinfo.cgi/webkit-changes

Reply via email to